﻿require "import"
import "java.text.SimpleDateFormat"
import "java.util.Date"
import "android.content.Context"
import "android.content.Intent"
import "android.content.IntentFilter"
import "android.os.BatteryManager"
import "android.bluetooth.BluetoothAdapter"
import "android.location.LocationManager"
import "android.os.Build"
import "android.telephony.TelephonyManager"
import "android.os.StatFs"
import "android.os.Environment"
import "android.provider.Settings"

-- Get current time
local formattedTime = SimpleDateFormat("HH:mm").format(Date())

-- Get current date
local formattedDate = SimpleDateFormat("EEEE, dd MMMM yyyy").format(Date())

-- Get battery level
local batteryIntent = this.registerReceiver(nil, IntentFilter(Intent.ACTION_BATTERY_CHANGED))
local level = batteryIntent.getIntExtra(BatteryManager.EXTRA_LEVEL, -1)
local scale = batteryIntent.getIntExtra(BatteryManager.EXTRA_SCALE, -1)
local batteryPercent = (level / scale) * 100

-- Get charging status
local status = batteryIntent.getIntExtra(BatteryManager.EXTRA_STATUS, -1)
local isCharging = status == BatteryManager.BATTERY_STATUS_CHARGING or status == BatteryManager.BATTERY_STATUS_FULL

-- Get current temperature
local temperature = batteryIntent.getIntExtra(BatteryManager.EXTRA_TEMPERATURE, 0) / 10

-- Get battery health
local health = batteryIntent.getIntExtra(BatteryManager.EXTRA_HEALTH, -1)
local batteryHealth = "desconhecido"
if health == BatteryManager.BATTERY_HEALTH_GOOD then
    batteryHealth = "boa"
elseif health == BatteryManager.BATTERY_HEALTH_OVERHEAT then
    batteryHealth = "superaquecido"
elseif health == BatteryManager.BATTERY_HEALTH_DEAD then
    batteryHealth = "ruim"
elseif health == BatteryManager.BATTERY_HEALTH_OVER_VOLTAGE then
    batteryHealth = "sobre tensão"
elseif health == BatteryManager.BATTERY_HEALTH_UNSPECIFIED_FAILURE then
    batteryHealth = "erro desconhecido"
elseif health == BatteryManager.BATTERY_HEALTH_COLD then
    batteryHealth = "fria"
end

-- Get Bluetooth status
local bluetoothAdapter = BluetoothAdapter.getDefaultAdapter()
local bluetoothStatus = bluetoothAdapter and (bluetoothAdapter.isEnabled() and "ligado" or "desligado") or "conectado"

-- Get network connection status
local connectivityManager = this.getSystemService(Context.CONNECTIVITY_SERVICE)
local activeNetworkInfo = connectivityManager.getActiveNetworkInfo()
local isConnected = activeNetworkInfo and activeNetworkInfo.isConnected
local internetStatus = isConnected and "ativado" or "desativado"

-- Get Airplane mode status
local isAirplaneModeOn = Settings.System.getInt(this.getContentResolver(), Settings.Global.AIRPLANE_MODE_ON, 0) == 1
local airplaneModeStatus = isAirplaneModeOn and "ativado" or "desativado"

-- Get Location status
local locationManager = this.getSystemService(Context.LOCATION_SERVICE)
local isLocationEnabled = locationManager.isProviderEnabled(LocationManager.GPS_PROVIDER)
local locationStatus = isLocationEnabled and "ativado" or "desativado"

-- Get device name
local deviceName = Build.MODEL

local telephonyManager = this.getSystemService(Context.TELEPHONY_SERVICE)
local simOperatorName = ""
local simCount = telephonyManager.getSimCount()
if simCount >= 1 then
    simOperatorName = telephonyManager.getSimOperatorName()
end

-- Get available storage
local storage = Environment.getExternalStorageDirectory()
local stat = StatFs(storage.getPath())
local availableBytes = stat.getAvailableBytes()
local availableGB = availableBytes / (1024^3)

-- Get memory card status
local isMemoryCardInserted = Environment.getExternalStorageState() == Environment.MEDIA_MOUNTED

-- Get screen brightness
local brightness = Settings.System.getInt(this.getContentResolver(), Settings.System.SCREEN_BRIGHTNESS)
local brightnessPercent = (brightness / 255) * 100

-- Create and speak the message
local chargingStatusMessage = isCharging and "Device is charging." or "Device is not charging."

local message = "hora atual: " .. formattedTime ..
                ". Data: " .. formattedDate ..
                ". nível de bateria: " .. string.format("%.0f", batteryPercent) .. "%" ..
                (isCharging and ". Carregando" or ". Não carregando") ..
                ". Temperatura atual do dispositivo: " .. temperature .. "°C" ..
                ". Saúde da bateria: " .. batteryHealth ..
                ". Bluetooth: " .. bluetoothStatus ..
                ". Rede de acesso a Интернет: " .. internetStatus ..
                ". Modo avião: " .. airplaneModeStatus ..
                ". Localização: " .. locationStatus ..
                ". Nome do dispositivo: " .. deviceName ..
                ". Operadora do cartão SIM: " .. simOperatorName ..
                ". Armazenamento disponível: " .. string.format("%.2f", availableGB) .. " GB" ..
                ". Cartão de memória: " .. (isMemoryCardInserted and "inserido" or "não inserido") ..
                ". Brilho da tela: " .. string.format("%.0f", brightnessPercent) .. "%"

this.speak(message)
return true